==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Anteeksi</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Edellistä peliä ei pystytty lataamaan. Uusi peli aloitetaan.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>Aikaa mennyt %1</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 askeleita otettu</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 kohdetta jäljellä</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Onnistuit</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pysäytetty</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Valitse ohjelman kieli:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Järjestelmän kieli&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Merkintä</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Uudelleenkäynnistä ohjelma muuttaaksesi kielen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Uusi peli</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Metsästä ja tapa</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Itseääntoistava jäljitin</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pino</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pino 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pino 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pino 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pino 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmi:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Kohteet:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Metsästä ja tapa</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Itseääntoistava jäljitin</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pino</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pino 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pino 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pino 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pino 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze pisteet</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pisteet</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Askeleet</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmi</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Onnittelut!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Pääsit kymmenen parhaan joukkoon.
Kirjoita nimesi:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Peli</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Näytä, missä olet käynyt</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Näytä askeleiden määrä</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Näytä kulunut aika</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Sujuva liikkuvuus</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Näppäimet</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Liiku ylös:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Liiku alas:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Liiku vasemmalle:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Liiku oikealle:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Vaihda lippua:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teemat</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Valitse teematiedosto</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Anteeksi</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Data-kansiota ei voitu luoda.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Teematiedostoa ei voitu kopioida.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Poista valittu teema?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Valittua teemaa ei voitu poistaa</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Tietoa &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Game</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;New</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>High &amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;In</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Out</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Settings</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Application &amp;Language...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferences...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;About</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Ylhäältäkuvattu labyrinttipeli</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Julkaistu &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisenssin alla</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikonit ovat &lt;a href=%1&gt;Oxygen&lt;/a&gt; teemasta</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Käytetään &lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisenssin alla</translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.2.orig.tar.gz: cutemaze-1.3.2/translations/cutemaze_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Anteeksi</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Edellistä peliä ei pystytty lataamaan. Uusi peli aloitetaan.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>Aikaa mennyt %1</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 askeleita otettu</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 kohdetta jäljellä</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Onnistuit</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pysäytetty</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Valitse ohjelman kieli:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Järjestelmän kieli&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Merkintä</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Uudelleenkäynnistä ohjelma muuttaaksesi kielen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Uusi peli</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Metsästä ja tapa</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Itseääntoistava jäljitin</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pino</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pino 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pino 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pino 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pino 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmi:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Kohteet:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pisteet</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Askeleet</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmi</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Onnittelut!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Peli</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Näytä, missä olet käynyt</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Näytä askeleiden määrä</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Näytä kulunut aika</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Sujuva liikkuvuus</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Näppäimet</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Liiku ylös:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Liiku alas:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Liiku vasemmalle:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Liiku oikealle:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Vaihda lippua:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teemat</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Valitse teematiedosto</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Anteeksi</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Data-kansiota ei voitu luoda.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Teematiedostoa ei voitu kopioida.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Poista valittu teema?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Valittua teemaa ei voitu poistaa</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Tietoa &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Game</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;New</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Hint</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>High &amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;In</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Out</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Settings</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Application &amp;Language...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferences...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;About</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Ylhäältäkuvattu labyrinttipeli</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Julkaistu &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisenssin alla</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikonit ovat &lt;a href=%1&gt;Oxygen&lt;/a&gt; teemasta</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Käytetään &lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisenssin alla</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
